@@ -74,7 +74,7 @@ class Minimizer:
         self.cache_file = cache_file
         if cache_file and os.path.exists(cache_file):
             with open(cache_file, encoding="utf8") as cache_fd:
-                cache = yaml.safe_load(cache_fd)
+                cache = yaml.load(cache_fd, Loader=yaml.CSafeLoader)
             self._load_constraints_from_cache(cache)
 
     def minimize(self):
@@ -119,16 +119,18 @@ class Minimizer:
             )
 
             try:
-                solution = self._no_objective_optimization()
-
-                if not self._check_solution(solution, selected, not_selected):
-                    logging.info(
-                        "Community Inconsistent: %s", str(list(selected.keys()))
-                    )
-                    self._add_knowledge_constraint(not_selected)
-                    continue
-
                 growth = 0
+
+                if not self.objective and not self.parsimony:
+                    solution = self._no_objective_optimization()
+
+                    if not self._check_solution(solution, selected, not_selected):
+                        logging.info(
+                            "Community Inconsistent: %s", str(list(selected.keys()))
+                        )
+                        self._add_knowledge_constraint(not_selected)
+                        continue
+
                 if self.objective:
                     objective_solution = self._objective_optimization()
                     if not self._check_solution(
@@ -260,6 +262,7 @@ class Minimizer:
                     "solutions": self.solutions,
                 },
                 cache_fd,
+                Dumper=yaml.CSafeDumper,
             )
 
     def _setup_parsimony(self):
@@ -274,7 +277,7 @@ class Minimizer:
         for rid in self.community.merged_model.reactions:
             self.solver.add_constraint(
                 f"c_{rid}_abs",
-                {f"abs_{rid}_pos": 1, f"abs_{rid}_neg": -1},
+                {f"abs_{rid}_pos": 1, f"abs_{rid}_neg": -1, rid: -1},
                 "=",
                 0,
             )
