@@ -72,7 +72,7 @@ def main(args):
     if args.validate:
         validate_solution_dict(output_dict, args.exchange_format)
 
-    output = yaml.dump(output_dict)
+    output = yaml.dump(output_dict, Dumper=yaml.CSafeDumper)
 
     if args.output:
         if not os.path.exists(os.path.dirname(args.output)):
@@ -93,10 +93,10 @@ def entry():
     communities can supply growth of some strain (or each other, if no strain
     is chosen).
 
-    It will report the results in `yaml` format, where the dictionaries contain
-    all active exchange reactions and their rates, as well as the activity of
-    strains (i.e. `y_strain: 1` for any active strain), the community growth
-    rate and the individual growth rates of all participating strains:
+    It will report the results in `yaml` format, where the dictionaries contain all
+    active exchange reactions and their rates, as well as the activity of strains (i.e.
+    `y_strain: 1` for any active strain), the community growth rate and the individual
+    growth rates of all participating strains:
 
         ```
         carbon_source:
